@@ -159,16 +159,6 @@ const unicodePropertyEscapeFixtures = [
 		]
 	},
 	// http://unicode.org/reports/tr18/#RL2.7
-	// {
-	// 	'path': 'Block/Alphabetic_Presentation_Forms',
-	// 	'expressions': [
-	// 		'blk=Alphabetic_PF',
-	// 		'blk=Alphabetic_Presentation_Forms',
-	// 		'Block=Alphabetic_PF',
-	// 		'Block=Alphabetic_Presentation_Forms'
-	// 	]
-	// },
-	// http://unicode.org/reports/tr18/#RL2.7
 	{
 		'path': 'Binary_Property/Bidi_Mirrored',
 		'expressions': [
@@ -461,64 +451,55 @@ const unicodePropertyEscapeFixtures = [
 	// 		'Bidi_Paired_Bracket_Type=Open'
 	// 	]
 	// },
-	// {
-	// 	'path': 'Block/Superscripts_And_Subscripts',
-	// 	'expressions': [
-	// 		'blk=Super_And_Sub',
-	// 		'blk=Superscripts_And_Subscripts',
-	// 		'Block=Super_And_Sub',
-	// 		'Block=Superscripts_And_Subscripts'
-	// 	]
-	// },
 	// http://unicode.org/reports/tr51/
 	{
-		'path': 'Emoji',
+		'path': 'Binary_Property/Emoji',
 		'expressions': [
 			'Emoji'
 		]
 	},
 	// http://unicode.org/reports/tr51/
 	{
-		'path': 'Emoji_Component',
+		'path': 'Binary_Property/Emoji_Component',
 		'expressions': [
 			'Emoji_Component'
 		]
 	},
 	// http://unicode.org/reports/tr51/
 	{
-		'path': 'Emoji_Modifier',
+		'path': 'Binary_Property/Emoji_Modifier',
 		'expressions': [
 			'Emoji_Modifier'
 		]
 	},
 	// http://unicode.org/reports/tr51/
 	{
-		'path': 'Emoji_Modifier_Base',
+		'path': 'Binary_Property/Emoji_Modifier_Base',
 		'expressions': [
 			'Emoji_Modifier_Base'
 		]
 	},
 	// http://unicode.org/reports/tr51/
 	{
-		'path': 'Emoji_Presentation',
+		'path': 'Binary_Property/Emoji_Presentation',
 		'expressions': [
 			'Emoji_Presentation'
 		]
 	},
 	// http://unicode.org/reports/tr51/proposed.html
-	{
-		'path': 'Extended_Pictographic',
-		'expressions': [
-			'Extended_Pictographic'
-		]
-	},
+	// TODO: uncomment once Unicode 11 is released and
+	// `Extended_Pictographic` makes it into the ECMAScript spec.
+	// {
+	// 	'path': 'Binary_Property/Extended_Pictographic',
+	// 	'expressions': [
+	// 		'Extended_Pictographic'
+	// 	]
+	// },
 ];
 
 const getPropertyValuePattern = (path) => {
-	const codePoints =
-		(path == 'Extended_Pictographic' || path.startsWith('Emoji')) ?
-		require(`unicode-tr51/${ path }.js`) :
-		require(`unicode-10.0.0/${ path }/code-points.js`);
+	const codePoints = require(`unicode-11.0.0/${
+		path }/code-points.js`);
 	return {
 		'p': regenerate(codePoints).toString(),
 		'P': UNICODE_SET.clone().remove(codePoints).toString()
@@ -758,3 +739,96 @@ describe('dotAllFlag', () => {
 		});
 	}
 });
+
+const namedGroupFixtures = [
+	{
+		'pattern': '(?<name>)\\k<name>',
+		'flags': '',
+		'expected': '()\\1',
+		'expectedGroups': [
+			['name', 1]
+		]
+	},
+	{
+		'pattern': '(?<name1>)(?<name2>)\\k<name1>\\k<name2>',
+		'flags': '',
+		'expected': '()()\\1\\2',
+		'expectedGroups': [
+			['name1', 1],
+			['name2', 2]
+		]
+	},
+	{
+		'pattern': '()(?<name>)\\k<name>',
+		'flags': '',
+		'expected': '()()\\2',
+		'expectedGroups': [
+			['name', 2]
+		]
+	},
+	{
+		'pattern': '(?<name>)()\\1',
+		'flags': '',
+		'expected': '()()\\1'
+	},
+	{
+		'pattern': '\\k<name>\\k<name>(?<name>)\\k<name>',
+		'flags': '',
+		'expected': '\\1\\1()\\1'
+	},
+	{
+		'pattern': '(?<name>\\k<name>)',
+		'flags': '',
+		'expected': '(\\1)'
+	}
+];
+
+describe('namedGroup', () => {
+	for (const fixture of namedGroupFixtures) {
+		const pattern = fixture.pattern;
+		const flags = fixture.flags;
+		const expected = fixture.expected;
+		const expectedGroups = fixture.expectedGroups;
+		it('rewrites `/' + pattern + '/' + flags + '` correctly', () => {
+			const groups = [];
+			const transpiled = rewritePattern(pattern, flags, {
+				'namedGroup': true,
+				'onNamedGroup': (name, index) => {
+					groups.push([ name, index ]);
+				}
+			});
+			assert.strictEqual(transpiled, expected);
+			if (expectedGroups) {
+				assert.deepStrictEqual(groups, expectedGroups);
+			}
+		});
+	}
+
+	it('onNamedGroup is optional', () => {
+		let transpiled;
+		const pattern = '(?<name>)';
+		const expected = '()';
+		assert.doesNotThrow(() => {
+			transpiled = rewritePattern('(?<name>)', '', {
+				'namedGroup': true
+			});
+		});
+		assert.strictEqual(transpiled, expected);
+	});
+
+	it('multiple groups with the same name are disallowed', () => {
+		assert.throws(() => {
+			rewritePattern('(?<name>)(?<name>)', '', {
+				'namedGroup': true
+			});
+		});
+	});
+
+	it('named references must reference a group', () => {
+		assert.throws(() => {
+			rewritePattern('\\k<name>', '', {
+				'namedGroup': true
+			});
+		});
+	});
+});
